cli

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2026 License: Apache-2.0 Imports: 18 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

Execute runs the root command.

Types

type EdgeDefinition

type EdgeDefinition struct {
	Description string   `json:"description" yaml:"description"`
	SourceTypes []string `json:"source_types" yaml:"source_types"`
	TargetTypes []string `json:"target_types" yaml:"target_types"`
}

EdgeDefinition represents an edge type in the ontology file.

type EntityDefinition

type EntityDefinition struct {
	Description string                     `json:"description" yaml:"description"`
	Fields      map[string]FieldDefinition `json:"fields" yaml:"fields"`
}

EntityDefinition represents an entity type in the ontology file.

type EpisodeData

type EpisodeData struct {
	Type string `json:"type"`
	Data string `json:"data"`
}

EpisodeData represents a single episode for batch import.

type EpisodeInput

type EpisodeInput struct {
	Episodes []EpisodeData `json:"episodes"`
}

EpisodeInput represents the input format for batch episodes.

type FieldDefinition

type FieldDefinition struct {
	Description string `json:"description" yaml:"description"`
}

FieldDefinition represents a field on an entity type.

type MessageData

type MessageData struct {
	Role     string         `json:"role"`
	Name     string         `json:"name,omitempty"`
	Content  string         `json:"content"`
	Metadata map[string]any `json:"metadata,omitempty"`
}

MessageData represents a single message.

type MessageInput

type MessageInput struct {
	Messages []MessageData `json:"messages"`
}

MessageInput represents the input format for adding messages.

type OntologyDefinition

type OntologyDefinition struct {
	Entities map[string]EntityDefinition `json:"entities" yaml:"entities"`
	Edges    map[string]EdgeDefinition   `json:"edges" yaml:"edges"`
}

OntologyDefinition represents the YAML/JSON file format for ontology.

Jump to